<?php

/**
 * @file
 * This file contains the Conditional Actions hooks and functions necessary to make the
 * order related entity, conditions, events, and actions work.
 */


/******************************************************************************
 * Conditional Actions Hooks                                                  *
 ******************************************************************************/

/**
* Implementation of hook_ca_trigger.
* Tell Ubercart about the various setcom triggers.
*/
function uc_setcom_ca_trigger() {
  $order_arg = array('#entity' => 'uc_order', '#label' => t('Order'));
  
  $triggers['setcom_payment_received'] = array(
    '#title' => t('Payment received'),
    '#category' => t('Setcom'),
    '#arguments' => array(
      'order' => $order_arg,
      'account' => array('#entity' => 'user', '#label' => t('customer user account'))
      ),
    );
  
  $triggers['setcom_payment_pending'] = array(
    '#title' => t('Payment pending'),
    '#category' => t('Setcom'),
    '#arguments' => array(
      'order' => $order_arg,
      'account' => array('#entity' => 'user', '#label' => t('customer user account'))
      ),
    );
  
  $triggers['setcom_payment_denied'] = array(
    '#title' => t('Payment denied'),
    '#category' => t('Setcom'),
    '#arguments' => array(
      'order' => $order_arg,
      'account' => array('#entity' => 'user', '#label' => t('customer user account'))
      ),
    );
  return $triggers;
}

/**
* Implementation of hook_ca_predicate)
*/
function uc_setcom_ca_predicate() {
  $configurations = array();
  $configurations['uc_setcom_payment_received'] = array(
    '#title' => t('Update order status on Setcom full payment'),
    '#description' => t('Only happens when a Setcom transaction was successful.'),
    '#class' => 'setcom',
    '#trigger' => 'setcom_payment_received',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_order_status_condition',
          '#title' => t('Check if the order status is pending.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'order_status' => 'pending',
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'uc_order_update_status',
        '#title' => t('Update the order status to Payment Received.'),
        '#argument_map' => array(
          'order' => 'order',
        ),
        '#settings' => array(
          'order_status' => 'setcom_payment_received',
        ),
      ),
    ),
  );
  
  $configurations['uc_setcom_payment_pending'] = array(
    '#title' => t('Update order status on Setcom payment pending'),
    '#description' => t('Only happens when a Setcom transaction was not completed. Most probably when payment must first be cleared.'),
    '#class' => 'setcom',
    '#trigger' => 'setcom_payment_pending',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_order_status_condition',
          '#title' => t('If the order status is pending.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'order_status' => 'pending',
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'uc_order_update_status',
        '#title' => t('Update the order status to Payment Received.'),
        '#argument_map' => array(
          'order' => 'order',
        ),
        '#settings' => array(
          'order_status' => 'setcom_payment_pending',
        ),
      ),
    ),
  );
  
  $configurations['uc_setcom_payment_denied'] = array(
    '#title' => t('Set order status to payment denied by Setcom'),
    '#description' => t('Only happens when a Setcom transaction was not successful.'),
    '#class' => 'setcom',
    '#trigger' => 'setcom_payment_denied',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_order_status_condition',
          '#title' => t('If the order status is pending.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'order_status' => 'pending',
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'uc_order_update_status',
        '#title' => t('Update the order status to Payment Denied.'),
        '#argument_map' => array(
          'order' => 'order',
        ),
        '#settings' => array(
          'order_status' => 'setcom_payment_denied',
        ),
      ),
    ),
  );
 return $configurations;
}  